@@ -1,6 +1,6 @@
 package AnyEvent::ProcessPool;
 # ABSTRACT: Asynchronously runs code concurrently in a pool of perl processes
-$AnyEvent::ProcessPool::VERSION = '0.02';
+$AnyEvent::ProcessPool::VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -60,10 +60,10 @@ sub DESTROY {
 }
 
 sub async {
-  my ($self, $code) = @_;
+  my ($self, $code, @args) = @_;
   my $id = next_id;
   $self->{complete}{$id} = AE::cv;
-  push @{$self->{queue}}, [$id, $code];
+  push @{$self->{queue}}, [$id, $code, \@args];
   $self->process_queue;
   return $self->{complete}{$id};
 }
@@ -74,10 +74,10 @@ sub process_queue {
   my $pool  = $self->{pool};
 
   while (@$queue && @$pool) {
-    my ($id, $code) = @{shift @$queue};
+    my ($id, $code, $args) = @{shift @$queue};
     my $worker = shift @$pool;
 
-    $self->{pending}{$id} = $worker->run($code);
+    $self->{pending}{$id} = $worker->run($code, $args);
 
     $self->{pending}{$id}->cb(sub{
       $self->{complete}{$id}->send(shift->recv);
@@ -103,7 +103,7 @@ AnyEvent::ProcessPool - Asynchronously runs code concurrently in a pool of perl
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -121,10 +121,6 @@ version 0.02
   # Block until result is ready
   my $result = $condvar->recv;
 
-  if ($result eq '...') {
-    ...
-  }
-
 =head1 DESCRIPTION
 
 Executes code using a pool a forked Perl subprocesses. Supports configurable
@@ -150,17 +146,29 @@ if it unexpectedly fails.
 
 =head2 async
 
-Executes the supplied code ref in a worker sub-process. Returns a
+Executes the supplied code ref in a worker sub-process. Remaining (optional)
+arguments are passed unchanged to the code ref in the worker process. Returns a
 L<condvar|AnyEvent/CONDITION VARIABLES> that will block and return the task
 result when C<recv> is called on it.
 
+  # With an anonymous subroutine
+  my $cv = $pool->async(sub{ ... });
+
+  # With a code ref
+  my $cv = $pool->async(\&do_stuff);
+
+  # With optional parameter list
+  my $cv = $pool->async(sub{ ... }, $arg1, $arg2, ...);
+
 =head2 join
 
-Blocks until all pending tasks have completed.
+Blocks until all pending tasks have completed. This does not prevent new tasks
+from being queued while waiting (for example, in the callback of an already
+queued task's condvar).
 
 =head1 PIPELINES
 
-Pipelinelines are another, sometimes simpler, way to use a process pool. See
+Pipelinelines are alternative way of using the process pool. See
 L<AnyEvent::ProcessPool::Pipeline> for details.
 
   use AnyEvent::ProcessPool::Pipeline;
