@@ -1,6 +1,6 @@
 package AnyEvent::ProcessPool::Worker;
 # ABSTRACT: The task executor code run in the worker process
-$AnyEvent::ProcessPool::Worker::VERSION = '0.02';
+$AnyEvent::ProcessPool::Worker::VERSION = '0.03';
 use strict;
 use warnings;
 use v5.10;
@@ -9,7 +9,7 @@ require AnyEvent::ProcessPool::Task;
 sub run {
   local $| = 1;
   while (defined(my $line = <STDIN>)) {
-    my $task = AnyEvent::ProcessPool::Task->new($line);
+    my $task = AnyEvent::ProcessPool::Task->decode($line);
     $task->execute;
     say $task->encode;
   }
@@ -29,7 +29,7 @@ AnyEvent::ProcessPool::Worker - The task executor code run in the worker process
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHOR
 
